VERSION 1.0 CLASS
BEGIN
  MultiUse = -1  'True
END
Attribute VB_Name = "CAnimateDlg"
Attribute VB_GlobalNameSpace = False
Attribute VB_Creatable = True
Attribute VB_PredeclaredId = False
Attribute VB_Exposed = True
Option Explicit
'
' CAnimateDlg Class
'
' Chris Eastwood 1998
'
' http://www.codeguru.com/vb
'
' This class is used to display an Animated
' Dialogue containing one of 6 AVI files stored
' in the Resource File for this project.
'
' Note: If you try and run this from the VBIDE
' you won't see any animated things at all !
'
' You'll have to compile it to a DLL and then
' set a reference to it.
'

' The AVI files all came with VB5 - feel free
' to add any other AVI's you like. Remember,
' the CreateWindowEX SysAnimate32 class cannot
' display AVI's which include sound.
'
' You'll also have to add to the Enumerated
' values to point to the new AVI in the resource
' file.
'

'
' Enumeration for our Available Animated Styles
'
' NOTE : These values point to the associated
'        avi in the RES file with the same ID
'
Public Enum aniType
    aniCopy = 1     ' Copy Dialog
    aniMove         ' Move Dialog
    aniDelete       ' Delete Dialog
    aniFind         ' Find Dialog
    aniSearch       ' Search Dialog
    aniPrint        ' Print Dialog
End Enum

'
' Init Common Controls Structure
'
Private Type tagInitCommonControlsEx
    lngSize As Long
    lngICC As Long
End Type
 
'
' Declaration to initialise common Controls
'
Private Declare Function InitCommonControlsEx Lib "Comctl32.dll" _
 (iccex As tagInitCommonControlsEx) As Boolean

'
' Declaration to create a Window using the Win32 API
'
Private Declare Function CreateWindowEx Lib "user32" _
    Alias "CreateWindowExA" (ByVal dwExStyle As Long, _
    ByVal lpClassName As String, ByVal lpWindowName As String, _
    ByVal dwStyle As Long, ByVal x As Long, ByVal y As Long, _
    ByVal nWidth As Long, ByVal nHeight As Long, _
    ByVal hwndParent As Long, ByVal hMenu As Long, _
    ByVal hInstance As Long, lpParam As Any) As Long

'
' Send Message Declaration (using ANY as lparam)
'
Private Declare Function SendMessage Lib "user32" _
    Alias "SendMessageA" (ByVal hwnd As Long, _
    ByVal wMsg As Long, ByVal wParam As Long, _
    lParam As Any) As Long
'
' Destroy Window Declaration
'
Private Declare Function DestroyWindow Lib "user32" (ByVal hwnd As Long) As Long

'
' Our created Animation Window HWND
'
Private lAnimHWND As Long
'
' Our created Static Window HWND
'
Private lStaticHWND As Long

'
' Our Form to contain the Animated Window
'
Private WithEvents mFrm As frmAnimate
Attribute mFrm.VB_VarHelpID = -1

'
' API Constants for Animated Window Classes
'
Private Const ICC_ANIMATE_CLASS As Long = &H80
Private Const ANIMATE_CLASS = "SysAnimate32"
Private Const WM_USER As Long = &H400&
Private Const ACS_CENTER As Long = &H1&
Private Const ACS_TRANSPARENT As Long = &H2&
Private Const ACS_AUTOPLAY As Long = &H4&
Private Const ACM_OPEN = WM_USER + 100
Private Const ACM_PLAY = WM_USER + 101
Private Const ACM_STOP = WM_USER + 102
Private Const WS_EX_TRANSPARENT As Long = &H20&

'
' Event Raised to controlling Application if Required
'
Public Event Cancelled()


Public Sub Create(ByVal aType As aniType, ByVal sFormCaption As String, _
    ByVal sLabelCaption As String, ByVal bAllowCancel As Boolean, _
    ByVal bDisplayProgressBar As Boolean)
'
' Setup the form captions / progress bar as required
'
    With mFrm
        .Caption = sFormCaption
        .lblDetails.Caption = sLabelCaption
        .cmdCancel.Visible = bAllowCancel
        .ProgressBar1.Visible = bDisplayProgressBar
        .ProgressBar1.Max = 100
        .ProgressBar1.Value = 0
        .Show
    End With
'
' Create the Static Window on our form
'
    lStaticHWND = CreateWindowEx(WS_EX_TRANSPARENT, _
        ANIMATE_CLASS, _
        "", _
         &H50000007, _
        -2, 0, 300, 60, _
        mFrm.hwnd, 0&, App.hInstance, ByVal 0&)
'
' Create the animation control on our form in the static window
'
    lAnimHWND = CreateWindowEx(WS_EX_TRANSPARENT, _
        ANIMATE_CLASS, _
        "", _
         &H50000007, _
        -2, 0, 300, 60, _
        lStaticHWND, 0&, App.hInstance, ByVal 0&)
'
' Tell the animated control to start animating
'
    SendMessage lAnimHWND, ACM_OPEN Or ACS_AUTOPLAY, 0&, ByVal CLng(aType)
'
' Now display and refresh our form
'
    With mFrm
        .Show
        .Refresh
        DoEvents
    End With
    
End Sub

Public Sub AnimatePlay()
'
' Animate Play method
'
    SendMessage lAnimHWND, ACM_PLAY, -1, 0
    mFrm.Refresh
End Sub

Public Sub AnimateStop()
'
' Animate Stop Method
'
    SendMessage lAnimHWND, ACM_STOP, 0, 0
    mFrm.Refresh
End Sub

Public Sub Destroy()
'
' Destroy Method - Kills the windows created
' with the CreateWindowEX api call
'
    If lAnimHWND <> 0 Then
        AnimateStop
        DestroyWindow lAnimHWND
        DestroyWindow lStaticHWND
        lAnimHWND = 0
        lStaticHWND = 0
    End If
    mFrm.Hide
End Sub

Public Sub AutoPlay()
'
' AutoPlay method
'
    SendMessage lAnimHWND, ACS_AUTOPLAY, -1, 0
    mFrm.Refresh
End Sub

Public Property Let LabelCaption(ByVal sCaption As String)
'
' Set the labels caption on the form
' This can be set while the animation is occuring
'
    mFrm.lblDetails.Caption = sCaption
    mFrm.Refresh
End Property

Public Property Let PercentDone(ByVal lPercent As Long)
'
' Set the Percentage Done value of the progress bar
' This can be set while the animation is occuring
'
    mFrm.ProgressBar1.Value = lPercent
End Property

Public Property Let Visible(ByVal bVal As Boolean)
'
' Show/Hide the form
'
    mFrm.Visible = bVal
End Property

Private Sub Class_Initialize()
'
' Initialise the Common Controls DLL
' You shouldn't have to do this, but you never know ...
'
    Dim iccex As tagInitCommonControlsEx
    
    With iccex
        .lngSize = LenB(iccex)
        .lngICC = ICC_ANIMATE_CLASS
    End With
    InitCommonControlsEx iccex
'
' Create our Form but don't show it
'
    Set mFrm = New frmAnimate
    Load mFrm
    
End Sub

Private Sub Class_Terminate()
'
' Kill any created windows
'
    Destroy
'
' Unload the Form
'
    Unload mFrm
    Set mFrm = Nothing
    
End Sub

Private Sub mFrm_Cancelled()
'
' User Pressed the cancel button on the form -
' raise this event to the calling application
'
    RaiseEvent Cancelled
End Sub
